DurationExtension<T extends String> extension

on

Properties

toDateTime → DateTime?

Available on String, provided by the DurationExtension extension

toDateTime extension this extension will convert a string into DateTime object
no setter
toDuration → Duration

Available on String, provided by the DurationExtension extension

toDuration extension this extension will convert a string into Duration object
no setter
toTimeOfDay → TimeOfDay

Available on String, provided by the DurationExtension extension

toTimeOfDay extension this extension will convert a string into TimeOfDay object
no setter

Methods

formatDateTime({String? newDateTimeFormat}) → String

Available on String, provided by the DurationExtension extension

formatDateTime extension method this extension method will convert a date time string into provided or default date time format string
formatTime({String? newTimeFormat}) → String

Available on String, provided by the DurationExtension extension

formatTime extension method this extension method will convert a date time string into provided or default time format string