StringExtension extension

on

Properties

isNullOrEmpty → bool

Available on String?, provided by the StringExtension extension

isNullOrEmpty extension this extension will check if the string is empty or null
no setter
replaceNullWithDouble → double

Available on String?, provided by the StringExtension extension

replaceNullWithDouble method this method will check and replace null with an double value
no setter
replaceNullWithEmpty → String

Available on String?, provided by the StringExtension extension

replaceNullWithEmpty method this method will check and replace null with an empty string
no setter
replaceNullWithZero → int

Available on String?, provided by the StringExtension extension

replaceNullWithZero extension this method will check and replace null with an integer value
no setter
replaceTrueOrFalse → int

Available on String?, provided by the StringExtension extension

replaceTrueOrFalse extension this method will check and replace true/false value with integer value
no setter
toDouble → double?

Available on String?, provided by the StringExtension extension

toDouble extension this method can be used on string as an extension to convert a string into double
no setter
toInt → int?

Available on String?, provided by the StringExtension extension

toInt extension this method can be used on string as an extension to convert a string into integer
no setter
toThreeDigits → String

Available on String?, provided by the StringExtension extension

toThreeDigits extension this extension will convert a string to three digits
no setter
toTwoDigits → String

Available on String?, provided by the StringExtension extension

toTwoDigits extension this extension will convert a string to two digits
no setter
trimLastChar → String

Available on String?, provided by the StringExtension extension

trimLastChar extension this extension will trim or remove last character from a string
no setter

Methods

toLengthOfString(dynamic lengthOfString) → String

Available on String?, provided by the StringExtension extension

toLengthOfString extension this extension will convert a string to the length specified