utils/utils library

Functions

convertBase64ToImage({required String base64}) → Future<Uint8List?>
convertImageToBase64({required String imagePath}) → Future<String?>
getAppVersion() → Future<String>
getAppVersion method this method will return the current version of the app
getCharFromString({required String stringToExtract}) → String
getCharFromString method this method will return characters from string passed
getDeviceId() → Future<String>
getDeviceId method this method will get device info like model name and device id
getDeviceName() → Future<String?>
getDeviceName method this method will get device or model name of the device
getNumbersFromString({String? stringToExtract}) → String?
getNumbersFromString method this method will return all the digits from string passed
getRandomMobileNumber() → String
getRandomMobileNumber method this method will return randomly generated mobile number
getRandomNumber({required int min, required int max}) → String
getRandomNumber method this method will return a random number between min and max number passed
getSingleDigitRandomNumber() → String
getSingleDigitRandomNumber method this method will return a single digit random number