DefaultButton class

This widget will build a custom shaped Button

Inheritance

Constructors

DefaultButton({Key? key, Color? btnColor, double height = 48, double elevation = 4, bool isEnabled = true, bool isUpperCase = false, EdgeInsetsGeometry margin = const EdgeInsets.only(top: 12), OutlinedBorder shape = const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(24))), TextStyle? btnTextStyle = const TextStyle(fontSize: 18, letterSpacing: 0.27, color: Colors.white, fontWeight: FontWeight.w700), required String? text, required VoidCallback? onPressed})
const

Properties

btnColor → Color?
final
btnTextStyle → TextStyle?
final
elevation → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
isEnabled → bool
final
isUpperCase → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry
final
onPressed → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → OutlinedBorder
final
text → String?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited